#
# spec file for package python3-Theano
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Theano
%define normal_build    ("%{name}" == "python3-Theano")
%define testsuite_build ("%{name}" == "python3-Theano-testsuite")
Version:        0.8.2
Release:        2.6
Summary:        A scientific python library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Source:         https://files.pythonhosted.org/packages/30/3d/2354fac96ca9594b755ec22d91133522a7db0caa0877165a522337d0ed73/Theano-%{version}.tar.gz
Source1:        python3-Theano.rpmlintrc
Url:            http://deeplearning.net/software/theano/
BuildArch:      noarch
Requires:       gcc-c++
Requires:       python3-numpy-devel
Requires:       python3-scipy
Requires:       python3-six
Suggests:       python3-nose
Suggests:       python3-nose-parameterized
%if %{testsuite_build}
BuildRequires:  python3-Theano = %{version}
BuildRequires:  python3-nose
BuildRequires:  python3-nose-parameterized
%endif %{testsuite_build}
BuildRequires:  fdupes
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Theano is a Python library that allows you to define, optimize, and
evaluate mathematical expressions involving multi-dimensional arrays
efficiently. 
Theano features:
* tight integration with numpy - Use numpy.ndarray in Theano-compiled
  functions.
* transparent use of a GPU - Perform data-intensive calculations up to
  140x faster than with CPU.(float32 only)
* symbolic differentiation - Let Theano do your derivatives.
* speed and stability optimizations – Get the right answer for log(1+x)
  even when x is really tiny.
* dynamic C code generation - Evaluate expressions faster.
* extensive unit-testing and self-verification – Detect and diagnose
  many types of mistake.

Theano has been powering large-scale computationally intensive scientific
investigations since 2007. But it is also approachable enough to be used
in the classroom (IFT6266 at the University of Montreal).


%prep
%setup -q -n Theano-%{version}

%build
python3 setup.py build

%install
%if %{normal_build}
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Prepare for update-alternatives usage
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in theano-cache theano-nose theano-test ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{py3_ver}
    ln -s -f %{_sysconfdir}/alternatives/$p %{buildroot}%{_bindir}/$p
done

# required files if cuda is used by theano
install -m 0644 theano/sandbox/cuda/*.cu* \
        %{buildroot}%{python3_sitelib}/theano/sandbox/cuda/
install -m 0644 theano/sandbox/samples_MRG31k3p_12_7_5.txt \
        %{buildroot}%{python3_sitelib}/theano/sandbox/

# replace duplicate .pyo/.pyc with hardlinks
%fdupes %{buildroot}%{_defaultdocdir}/%{name}
%fdupes %{buildroot}%{python3_sitelib}

# Fix python-bytecode-inconsistent-mtime
pushd %{buildroot}%{python3_sitelib}
%py3_compile .
popd
%endif

%check
%if %{testsuite_build}
export THEANO_FLAGS=device=cpu
python3 ./bin/theano-nose
%endif

%post
%_sbindir/update-alternatives \
   --install %{_bindir}/theano-cache theano-cache %{_bindir}/theano-cache-%{py3_ver} 30 \
   --slave %{_bindir}/theano-nose theano-nose %{_bindir}/theano-nose-%{py3_ver} \
   --slave %{_bindir}/theano-test theano-test %{_bindir}/theano-test-%{py3_ver}

%postun
if [ $1 -eq 0 ] ; then
    %_sbindir/update-alternatives --remove theano-cache %{_bindir}/theano-cache-%{py3_ver}
fi

%if %{normal_build}
%files
%defattr(-,root,root)
%doc DESCRIPTION.txt EMAIL.txt HISTORY.txt NEWS.txt README.txt doc/LICENSE.txt
%{_bindir}/theano-cache
%{_bindir}/theano-nose
%{_bindir}/theano-test
%{_bindir}/theano-cache-%{py3_ver}
%{_bindir}/theano-nose-%{py3_ver}
%{_bindir}/theano-test-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/theano-cache
%ghost %{_sysconfdir}/alternatives/theano-nose
%ghost %{_sysconfdir}/alternatives/theano-test
%{python3_sitelib}/theano
%{python3_sitelib}/Theano-%{version}-*.egg-info
%endif

%changelog
* Mon Feb 13 2017 matwey.kornilov@gmail.com
- Add -testsuite package to run tests
* Sat Feb 11 2017 toddrme2178@gmail.com
- Initial python3 version
* Sat Feb 11 2017 toddrme2178@gmail.com
- Fix source URL
- Add license and basic doc files
- Implement update-alternatives
* Tue Aug 23 2016 jmatejek@suse.com
- update to 0.8.2
  * improved source packaging
  * renewed development
  * python2/3 compatibility
  * performance improvements
  * new GPU backends
- dropped doc subpackage as the source is no longer configured
  to rebuild the docs
- cleared out Requires and BuildRequires list
- do not delete first line of every .py file (fixes boo#994408)
* Sat Jul 26 2014 scorot@free.fr
- version 0.6.0 git 20140726
  * Many updates and bug fixes since 0.5.0, for a full list of
    changes see https://pypi.python.org/pypi/Theano/
- package is now noarch except for SLE 11
- update rpmlintrc file
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jun 20 2012 scorot@free.fr
- fix wrong characters in package description
* Wed Jun 20 2012 scorot@free.fr
- rename package to match the upstream name an modify spec file
  accordingly
- fix bytecode mtime inconsistency
* Sun Jun 17 2012 scorot@free.fr
- do not define %%%%DOCDIR but use %%%%_defaultdocdir instead
- update to git snapshot 20120617
  * No changelog available
* Sun Jun 17 2012 scorot@free.fr
- spec file cleanup
- do not require nvidia-cuda-toolkit
* Sun May 13 2012 scorot@free.fr
- spec file cleanup
- checkout upstream git 20120513
* Sat Feb 18 2012 scorot@free.fr
- update to version 0.5.0.git20120218
